summaryrefslogtreecommitdiffstats
path: root/lib/kformula/matrixelement.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kformula/matrixelement.h')
-rw-r--r--lib/kformula/matrixelement.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/lib/kformula/matrixelement.h b/lib/kformula/matrixelement.h
index ede10114..04203257 100644
--- a/lib/kformula/matrixelement.h
+++ b/lib/kformula/matrixelement.h
@@ -69,7 +69,7 @@ public:
* is allowed to set the cursor.
*/
virtual BasicElement* goToPos( FormulaCursor*, bool& handled,
- const LuPixelPoint& point, const LuPixelPoint& tqparentOrigin );
+ const LuPixelPoint& point, const LuPixelPoint& parentOrigin );
// drawing
//
@@ -80,7 +80,7 @@ public:
/**
* Calculates our width and height and
- * our tqchildren's tqparentPosition.
+ * our tqchildren's parentPosition.
*/
virtual void calcSizes( const ContextStyle& cstyle,
ContextStyle::TextStyle tstyle,
@@ -89,15 +89,15 @@ public:
/**
* Draws the whole element including its tqchildren.
* The `tqparentOrigin' is the point this element's tqparent starts.
* We can use our tqparentPosition to get our own origin then.
*/
virtual void draw( TQPainter& painter, const LuPixelRect& r,
const ContextStyle& context,
ContextStyle::TextStyle tstyle,
ContextStyle::IndexStyle istyle,
StyleAttributes& style,
- const LuPixelPoint& tqparentOrigin );
+ const LuPixelPoint& parentOrigin );
/**
* Dispatch this FontCommand to all our TextElement tqchildren.
@@ -271,7 +271,7 @@ private:
VerticalAlign m_align;
TQValueList< VerticalAlign > m_rowAlign;
TQValueList< HorizontalAlign > m_columnAlign;
- TQValueList< bool > m_tqalignmentScope;
+ TQValueList< bool > m_alignmentScope;
TQValueList< SizeType > m_columnWidthType;
TQValueList< double > m_columnWidth;
SizeType m_widthType;
@@ -337,7 +337,7 @@ public:
* Returns the element the point is in.
*/
BasicElement* goToPos( FormulaCursor* cursor, bool& handled,
- const LuPixelPoint& point, const LuPixelPoint& tqparentOrigin );
+ const LuPixelPoint& point, const LuPixelPoint& parentOrigin );
/**
* Sets the cursor inside this element to its start position.
@@ -375,7 +375,7 @@ public:
/**
* Calculates our width and height and
- * our tqchildren's tqparentPosition.
+ * our tqchildren's parentPosition.
*/
virtual void calcSizes( const ContextStyle& cstyle,
ContextStyle::TextStyle tstyle,
@@ -384,15 +384,15 @@ public:
/**
* Draws the whole element including its tqchildren.
* The `tqparentOrigin' is the point this element's tqparent starts.
* We can use our tqparentPosition to get our own origin then.
*/
virtual void draw( TQPainter& painter, const LuPixelRect& r,
const ContextStyle& context,
ContextStyle::TextStyle tstyle,
ContextStyle::IndexStyle istyle,
StyleAttributes& style,
- const LuPixelPoint& tqparentOrigin );
+ const LuPixelPoint& parentOrigin );
/**
* Dispatch this FontCommand to all our TextElement tqchildren.
@@ -89,15 +89,15 @@ public:
/**
* Draws the whole element including its tqchildren.
- * The `tqparentOrigin' is the point this element's tqparent starts.
- * We can use our tqparentPosition to get our own origin then.
+ * The `parentOrigin' is the point this element's tqparent starts.
+ * We can use our parentPosition to get our own origin then.
*/
virtual void draw( TQPainter& painter, const LuPixelRect& r,
@@ -384,15 +384,15 @@ public:
/**
* Draws the whole element including its tqchildren.
- * The `tqparentOrigin' is the point this element's tqparent starts.
- * We can use our tqparentPosition to get our own origin then.
+ * The `parentOrigin' is the point this element's tqparent starts.
+ * We can use our parentPosition to get our own origin then.
*/
virtual void draw( TQPainter& painter, const LuPixelRect& r,